/**
 * @packageDocumentation
 * @module Number
 */
import { MonoTypeOperatorFunction } from 'rxjs';
/**
 * Returns an Observable that emits only valid finite floating point numbers from a source
 *
 * @category Filter
 *
 * @see The [[isFloat]] operator returns a boolean value instead of the number
 *
 * @example
 * Return only values that are floating point numbers
 * ```ts
 * const input = [-10, -2.3, 0, 1, 2, 3.14, 4.2, 10, 11, 42];
 * from(input).pipe(filterIsFloat()).subscribe();
 * ```
 * Output: `-2.3, 3.14, 4.2`
 *
 * @returns Observable that emits valid finite floating point numbers
 */
export declare function filterIsFloat(): MonoTypeOperatorFunction<number>;
