/**
 * @packageDocumentation
 * @module Number
 */
import { Observable } from 'rxjs';
/**
 * Returns an Observable that emits a sequence of numbers in the
 * {@link https://en.wikipedia.org/wiki/Fibonacci_number|Fibonacci} sequence, starting from `0`
 *
 * @category Create
 *
 * @param iterations The number of iterations to do, must be greater than `0`
 * @param emitDelay If set the observable will emit per millisecond set, by default this is 0
 *
 * @example
 * Emit the first 5 numbers of the Fibonacci sequence immediately
 * ```ts
 * fromFibonacci(5).subscribe();
 * ```
 * Output: `0, 1, 1, 2, 3`
 *
 * @example
 * Emit the first 10 numbers of the Fibonacci sequence once per second, and skip `0`
 * ```ts
 * fromFibonacci(10, 1000).pipe(skip(1)).subscribe();
 * ```
 * Output: `1, 1, 2, 3, 5, 8, 13, 21, 34`
 *
 * @returns Observable of a Fibonacci sequence of numbers starting from `0`
 */
export declare function fromFibonacci(iterations: number, emitDelay?: number): Observable<number>;
