/**
 * @packageDocumentation
 * @module Number
 */
import { OperatorFunction, Subscribable } from 'rxjs';
/**
 * Returns an Observable that emits the median number value from an Iterable of numbers
 *
 * @category Distribution
 *
 * @example
 * Return the median of the source number Array
 * ```ts
 * const source$ = from([ [1, 2, 3], [10, 15, 8], [5, 10, 100] ]);
 *
 * source$.pipe(median()).subscribe();
 * ```
 * Output: `2, 15, 52.5`
 *
 * @returns Observable that emits a number that is the median value in the source Iterable
 */
export declare function median(precision?: Subscribable<number> | number): OperatorFunction<Iterable<number>, number>;
