/**
 * @packageDocumentation
 * @module Number
 */
import { OperatorFunction } from 'rxjs';
/**
 * Returns an Observable that emits the minimum number value from an Iterable of numbers
 *
 * @category Distribution
 *
 * @example
 * Return the min of the source number Array
 * ```ts
 * const source$ = from([ [1, 2, 3], [10, 15, 8], [5, 10, 100] ]);
 *
 * source$.pipe(min()).subscribe();
 * ```
 * Output: `1, 8, 5`
 *
 * @returns Observable that emits a number that is the minimum value in the source Iterable
 */
export declare function min(): OperatorFunction<Iterable<number>, number>;
